@@ -15,6 +15,7 @@ class FieldABC:
 
     parent = None
     name = None
+    root = None
 
     def serialize(self, attr, obj, accessor=None):
         raise NotImplementedError
@@ -50,6 +51,6 @@ class SchemaABC:
         many: typing.Optional[bool] = None,
         partial=None,
         unknown=None,
-        **kwargs
+        **kwargs,
     ):
         raise NotImplementedError
